@@ -109,7 +109,7 @@ NPY_NO_EXPORT  char * PyArray_Zero \
        (PyArrayObject *);
 NPY_NO_EXPORT  char * PyArray_One \
        (PyArrayObject *);
-NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) NPY_GCC_NONNULL(2) PyObject * PyArray_CastToType \
+NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) PyObject * PyArray_CastToType \
        (PyArrayObject *, PyArray_Descr *, int);
 NPY_NO_EXPORT  int PyArray_CastTo \
        (PyArrayObject *, PyArrayObject *);
@@ -165,9 +165,9 @@ NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) PyObject * PyArray_FromIter \
        (PyObject *, PyArray_Descr *, npy_intp);
 NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(1) PyObject * PyArray_Return \
        (PyArrayObject *);
-NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) NPY_GCC_NONNULL(2) PyObject * PyArray_GetField \
+NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) PyObject * PyArray_GetField \
        (PyArrayObject *, PyArray_Descr *, int);
-NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) NPY_GCC_NONNULL(2) int PyArray_SetField \
+NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) int PyArray_SetField \
        (PyArrayObject *, PyArray_Descr *, int, PyObject *);
 NPY_NO_EXPORT  PyObject * PyArray_Byteswap \
        (PyArrayObject *, npy_bool);
@@ -181,7 +181,7 @@ NPY_NO_EXPORT  int PyArray_CopyAnyInto \
        (PyArrayObject *, PyArrayObject *);
 NPY_NO_EXPORT  int PyArray_CopyObject \
        (PyArrayObject *, PyObject *);
-NPY_NO_EXPORT NPY_GCC_NONNULL(1) PyObject * PyArray_NewCopy \
+NPY_NO_EXPORT  PyObject * PyArray_NewCopy \
        (PyArrayObject *, NPY_ORDER);
 NPY_NO_EXPORT  PyObject * PyArray_ToList \
        (PyArrayObject *);
@@ -197,9 +197,9 @@ NPY_NO_EXPORT  int PyArray_ValidType \
        (int);
 NPY_NO_EXPORT  void PyArray_UpdateFlags \
        (PyArrayObject *, int);
-NPY_NO_EXPORT NPY_GCC_NONNULL(1) PyObject * PyArray_New \
+NPY_NO_EXPORT  PyObject * PyArray_New \
        (PyTypeObject *, int, npy_intp const *, int, npy_intp const *, void *, int, int, PyObject *);
-NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) NPY_GCC_NONNULL(1) NPY_GCC_NONNULL(2) PyObject * PyArray_NewFromDescr \
+NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(2) PyObject * PyArray_NewFromDescr \
        (PyTypeObject *, PyArray_Descr *, int, npy_intp const *, npy_intp const *, void *, int, PyObject *);
 NPY_NO_EXPORT  PyArray_Descr * PyArray_DescrNew \
        (PyArray_Descr *);
@@ -565,7 +565,7 @@ NPY_NO_EXPORT  npy_bool PyArray_CanCastTypeTo \
        (PyArray_Descr *, PyArray_Descr *, NPY_CASTING);
 NPY_NO_EXPORT  PyArrayObject * PyArray_EinsteinSum \
        (char *, npy_intp, PyArrayObject **, PyArray_Descr *, NPY_ORDER, NPY_CASTING, PyArrayObject *);
-NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(3) NPY_GCC_NONNULL(1) PyObject * PyArray_NewLikeArray \
+NPY_NO_EXPORT NPY_STEALS_REF_TO_ARG(3) PyObject * PyArray_NewLikeArray \
        (PyArrayObject *, NPY_ORDER, PyArray_Descr *, int);
 NPY_NO_EXPORT  int PyArray_GetArrayParamsFromObject \
        (PyObject *NPY_UNUSED(op), PyArray_Descr *NPY_UNUSED(requested_dtype), npy_bool NPY_UNUSED(writeable), PyArray_Descr **NPY_UNUSED(out_dtype), int *NPY_UNUSED(out_ndim), npy_intp *NPY_UNUSED(out_dims), PyArrayObject **NPY_UNUSED(out_arr), PyObject *NPY_UNUSED(context));
@@ -611,7 +611,7 @@ NPY_NO_EXPORT  int PyArray_SelectkindConverter \
        (PyObject *, NPY_SELECTKIND *);
 NPY_NO_EXPORT  void * PyDataMem_NEW_ZEROED \
        (size_t, size_t);
-NPY_NO_EXPORT NPY_GCC_NONNULL(1) int PyArray_CheckAnyScalarExact \
+NPY_NO_EXPORT  int PyArray_CheckAnyScalarExact \
        (PyObject *);
 NPY_NO_EXPORT  PyObject * PyArray_MapIterArrayCopyIfOverlap \
        (PyArrayObject *, PyObject *, int, PyArrayObject *);
@@ -619,6 +619,12 @@ NPY_NO_EXPORT  int PyArray_ResolveWritebackIfCopy \
        (PyArrayObject *);
 NPY_NO_EXPORT  int PyArray_SetWritebackIfCopyBase \
        (PyArrayObject *, PyArrayObject *);
+NPY_NO_EXPORT  PyObject * PyDataMem_SetHandler \
+       (PyObject *);
+NPY_NO_EXPORT  PyObject * PyDataMem_GetHandler \
+       (void);
+extern NPY_NO_EXPORT PyObject* PyDataMem_DefaultHandler;
+
 
 #else
 
@@ -1458,6 +1464,13 @@ static void **PyArray_API=NULL;
 #define PyArray_SetWritebackIfCopyBase \
         (*(int (*)(PyArrayObject *, PyArrayObject *)) \
          PyArray_API[303])
+#define PyDataMem_SetHandler \
+        (*(PyObject * (*)(PyObject *)) \
+         PyArray_API[304])
+#define PyDataMem_GetHandler \
+        (*(PyObject * (*)(void)) \
+         PyArray_API[305])
+#define PyDataMem_DefaultHandler (*(PyObject* *)PyArray_API[306])
 
 #if !defined(NO_IMPORT_ARRAY) && !defined(NO_IMPORT)
 static int
